==> jc-1.4.0.tar.gz: java/beans/beancontext/BeanContextEvent.h <==
// public abstract class java.beans.beancontext.BeanContextEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_beans_beancontext_BeanContextEvent_H_
#define _JC_java_beans_beancontext_BeanContextEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextEvent$sub_refs	_jc_java_beans_beancontext_BeanContextEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$refs	_jc_java_beans_beancontext_BeanContextEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$nonrefs	_jc_java_beans_beancontext_BeanContextEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$object	_jc_java_beans_beancontext_BeanContextEvent$object;

typedef struct _jc_java_beans_beancontext_BeanContextEvent$fields_struct	_jc_java_beans_beancontext_BeanContextEvent$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vmethods	_jc_java_beans_beancontext_BeanContextEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vtable	_jc_java_beans_beancontext_BeanContextEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vtype	_jc_java_beans_beancontext_BeanContextEvent$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextEvent$fields_struct _jc_java_beans_beancontext_BeanContextEvent$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextEvent$method$_init$933d945eb5da4d7f(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextEvent$method$getBeanContext$fb8fea20f7b829a1(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextEvent$method$getPropagatedFrom$69159ae594cb03f2(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
extern jboolean _jc_java_beans_beancontext_BeanContextEvent$method$isPropagated$712c2965d22edceb(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
extern void _jc_java_beans_beancontext_BeanContextEvent$method$setPropagatedFrom$c3664e7227bf8798(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$getBeanContext$fb8fea20f7b829a1;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$getPropagatedFrom$69159ae594cb03f2;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$isPropagated$712c2965d22edceb;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$setPropagatedFrom$c3664e7227bf8798;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextEvent$vmethods {
	struct _jc_object	*(*getBeanContext$fb8fea20f7b829a1)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
	struct _jc_object	*(*getPropagatedFrom$69159ae594cb03f2)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
	jboolean	(*isPropagated$712c2965d22edceb)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *);
	void	(*setPropagatedFrom$c3664e7227bf8798)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *);
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextEvent$sub_refs {
	struct _jc_object	*propagatedFrom;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextEvent$refs {
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextEvent$object {
	_jc_java_beans_beancontext_BeanContextEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextEvent$vtype _jc_java_beans_beancontext_BeanContextEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextEvent_H_ */

==> jc-1.4.6.tar.gz: java/beans/beancontext/BeanContextEvent.h <==
// public abstract class java.beans.beancontext.BeanContextEvent

// class file dependencies
// @dep_class 83892d580401761a java_beans_beancontext_BeanContextEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_beans_beancontext_BeanContextEvent_H_
#define _JC_java_beans_beancontext_BeanContextEvent_H_

// Forward structure declarations
struct _jc_java_beans_beancontext_BeanContext$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_beans_beancontext_BeanContextEvent$sub_refs	_jc_java_beans_beancontext_BeanContextEvent$sub_refs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	_jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$refs	_jc_java_beans_beancontext_BeanContextEvent$refs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$nonrefs	_jc_java_beans_beancontext_BeanContextEvent$nonrefs;
typedef struct _jc_java_beans_beancontext_BeanContextEvent$object	_jc_java_beans_beancontext_BeanContextEvent$object;

typedef struct _jc_java_beans_beancontext_BeanContextEvent$fields_struct	_jc_java_beans_beancontext_BeanContextEvent$fields_struct;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vmethods	_jc_java_beans_beancontext_BeanContextEvent$vmethods;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vtable	_jc_java_beans_beancontext_BeanContextEvent$vtable;
typedef const struct _jc_java_beans_beancontext_BeanContextEvent$vtype	_jc_java_beans_beancontext_BeanContextEvent$vtype;

// Class fields structure
struct _jc_java_beans_beancontext_BeanContextEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_beans_beancontext_BeanContextEvent$fields_struct _jc_java_beans_beancontext_BeanContextEvent$class_fields;

// Constructors
extern void _jc_java_beans_beancontext_BeanContextEvent$method$_init$933d945eb5da4d7f(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextEvent$method$getBeanContext$fb8fea20f7b829a1(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_beancontext_BeanContextEvent$method$getPropagatedFrom$69159ae594cb03f2(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_beans_beancontext_BeanContextEvent$method$isPropagated$712c2965d22edceb(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_beancontext_BeanContextEvent$method$setPropagatedFrom$c3664e7227bf8798(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$getBeanContext$fb8fea20f7b829a1;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$getPropagatedFrom$69159ae594cb03f2;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$isPropagated$712c2965d22edceb;
extern _jc_method _jc_java_beans_beancontext_BeanContextEvent$method_info$setPropagatedFrom$c3664e7227bf8798;

// Virtual methods structure
struct _jc_java_beans_beancontext_BeanContextEvent$vmethods {
	struct _jc_object	*(*getBeanContext$fb8fea20f7b829a1)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPropagatedFrom$69159ae594cb03f2)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isPropagated$712c2965d22edceb)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *) _JC_JCNI_ATTR;
	void	(*setPropagatedFrom$c3664e7227bf8798)(_jc_env *, struct _jc_java_beans_beancontext_BeanContextEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_beancontext_BeanContextEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_beans_beancontext_BeanContextEvent$vmethods	java_beans_beancontext_BeanContextEvent;
};

// Vtype
struct _jc_java_beans_beancontext_BeanContextEvent$vtype {
	_jc_type			type;
	_jc_java_beans_beancontext_BeanContextEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextEvent$sub_refs {
	struct _jc_object	*propagatedFrom;
};

// Reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextEvent$refs {
    _jc_java_beans_beancontext_BeanContextEvent$sub_refs	java_beans_beancontext_BeanContextEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_beancontext_BeanContextEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_beans_beancontext_BeanContextEvent$sub_nonrefs	java_beans_beancontext_BeanContextEvent;
};

// Object instance structure
struct _jc_java_beans_beancontext_BeanContextEvent$object {
	_jc_java_beans_beancontext_BeanContextEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_beancontext_BeanContextEvent$vtype	*vtype;
	_jc_java_beans_beancontext_BeanContextEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_beancontext_BeanContextEvent$vtype _jc_java_beans_beancontext_BeanContextEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_beancontext_BeanContextEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_beancontext_BeanContextEvent$class_object;

#endif	/* _JC_java_beans_beancontext_BeanContextEvent_H_ */
